@@ -289,12 +289,12 @@ def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_p
                                _scan_for_device_type,
                                _calling_software):
     """
-    Evaluates whether a bluetooth of WiFi device can be detected.
+    Evaluates whether bluetooth of WiFi devices as listed in the _wifi_devices_dict can be detected
     :param: _wifi_devices_dict: dict, contains the wifi devices name and Mac address
     :param: _router_ip_address: string, contains the routers ip address
     :param: _router_password: string, contains the routers password
     :param: _bluetooth_devices_dict: dict, contains the bluetooth devices name and Mac address
-    :param: _scan_for_device_type: string, contains the scan type "bluetooth" or "WiFi" or "both"
+    :param: _scan_for_device_type: string, contains the scan type "bluetooth" or "wifi"
     :param: _calling_software: string, contains the which software is calling this function "rha" or "pir"
     :returns: bool, device in dictionaries _wifi_devices_dict or  _bluetooth_devices_dict are present
     """
@@ -325,32 +325,21 @@ def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_p
     def mobile_device_presence():
         bluetooth_key, bluetooth_bool = scan_bluetooth()
         wifi_key, wifi_bool = scan_wifi()
-        if _scan_for_device_type == "bluetooth":
-            if _calling_software == "pir":
-                return bluetooth_key, bluetooth_bool
-            elif _calling_software == "rha":
-                return bluetooth_bool
-        elif _scan_for_device_type == "wifi":
+        if (_scan_for_device_type == "wifi") or (not bluetooth_bool):
             if _calling_software == "pir":
                 return wifi_key, wifi_bool
             elif _calling_software == "rha":
                 return wifi_bool
-        elif _scan_for_device_type == "both":
-            if bluetooth_key is None and wifi_key is None:
-                if _calling_software == "pir":
-                    return None, False
-                elif _calling_software == "rha":
-                    return False
-            elif wifi_key is not None:
-                if _calling_software == "pir":
-                    return wifi_key, wifi_bool
-                elif _calling_software == "rha":
-                    return wifi_bool
-            elif bluetooth_key is not None:
-                if _calling_software == "pir":
-                    return bluetooth_key, bluetooth_bool
-                elif _calling_software == "rha":
-                    return bluetooth_bool
+        elif (_scan_for_device_type == "bluetooth") or (not wifi_bool):
+            if _calling_software == "pir":
+                return bluetooth_key, bluetooth_bool
+            elif _calling_software == "rha":
+                return bluetooth_bool
+        else:
+            if _calling_software == "pir":
+                return None, False
+            elif _calling_software == "rha":
+                return False
 
     return mobile_device_presence
 
